﻿using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Layout;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using System.Drawing;

// Initialize GcPdfDocument
var doc = new GcPdfDocument();

//Set page width and height
float pageW = 1250;
float pageH = 600;

// Add a page to the PDF document
var page = doc.Pages.Add(new SizeF(pageW, pageH));

// Initialize GcPdfGraphics
var g = page.Graphics;

// Initialize LayoutHost
var host = new LayoutHost();

// Create LayoutView
var view = host.CreateView(pageW, pageH);

// Create LayoutRect. Add anchor points
var rt = view.CreateRect();
rt.AnchorTopLeft(null, 36, 36);

// Create an instance of TableRenderer
var ta = new TableRenderer(g,
    rt, FixedTableSides.TopLeft,
    rowCount: 6, columnCount: 6,
    gridLineColor: Color.FromArgb(112,112,112),
    gridLineWidth: 1);

// Set height and width of the the rows and columns
ta.RowRects[0].SetHeight(74);
ta.ColumnRects[0].SetWidth(144);

// Set the cell style
var cs = new CellStyle
{
    TextAlignment = TextAlignment.Center,
    ParagraphAlignment = ParagraphAlignment.Center,

    // Set text format
    TextFormat = new TextFormat
    {
        FontName = "Roboto",
        FontSize = 16,
        FontSizeInGraphicUnits = true,
        FontBold = true        
    }
};

// Add even row header cell style
var evenCellStyle = new CellStyle(cs)
{   
    FillColor = Color.FromArgb(250, 250, 250)   
};

//Define cell style for column header cells
var csColumnHeader = new CellStyle(cs)
{    
    FillColor = Color.FromArgb(243, 244, 246),  
};

// Add a background style for displaying the header text "Project"
// with a custom drawn element (diagonal line)
var csCornerTopRight = new CellStyle(cs)
{
    Background = true,
    FillColor = Color.FromArgb(243, 244, 246),
    LineWidth = 1f,
    Borders = FrameBorders.MainDiagonal,
    TextAlignment = TextAlignment.Trailing,
    ParagraphAlignment = ParagraphAlignment.Near,
    PaddingRight = 8,
    PaddingTop = 4,

    // Set text format
    TextFormat = new TextFormat
    {
        FontName = "Roboto",
        FontSize = 18,
        FontSizeInGraphicUnits = true,
        FontBold = true
    }
};

// Add a regular style for displaying the header text "PM" at the bottom
// left corner of the same cell.
var csCornerBottomLeft = new CellStyle(cs)
{
    TextAlignment = TextAlignment.Leading,
    ParagraphAlignment = ParagraphAlignment.Far,
    PaddingLeft = 15,
    PaddingBottom = 5,    

    // Set text format
    TextFormat = new TextFormat
    {
        FontName = "Roboto",
        FontSize = 18,
        FontSizeInGraphicUnits = true,
        FontBold = true
    }
};

// Add a background cell at the top left corner
ta.AddCell(csCornerTopRight, 0, 0, "Project");

// Add column header cells
ta.AddCell(csColumnHeader, 0, 1, "Inventory Management");
ta.AddCell(csColumnHeader, 0, 2, "Spell Checker");
ta.AddCell(csColumnHeader, 0, 3, "Audit Engine");
ta.AddCell(csColumnHeader, 0, 4, "Retail Process");
ta.AddCell(csColumnHeader, 0, 5, "Evaluation Report");

// Add a regular cell at the top left corner
ta.AddCell(csCornerBottomLeft, 0, 0, "PM");

// Add row header cells
ta.AddCell(cs, 1, 0, "Jim Kon");
ta.AddCell(evenCellStyle, 2, 0, "Ted Baker");
ta.AddCell(cs, 3, 0, "John Meyers");
ta.AddCell(evenCellStyle, 4, 0, "James Brown");
ta.AddCell(cs, 5, 0, "Michael Kin");

// Add default cell style
ta.DefaultCellStyle = new CellStyle
{
    PaddingTop = 15,
    PaddingLeftRight = 20,
    PaddingBottom = 55,
    FixedWidth = false,    
    TextAlignment = TextAlignment.Center,
    TextFormat = new TextFormat
    {
        FontName = "Roboto",
        FontSize = 16,
        FontBold = false
    },

    // Set text layout
    CreateTextLayout = (g, cs, data) =>
    {
        var tl = g.CreateTextLayout();
        tl.Append(((Task)data).Title, cs.TextFormat);
        return tl;
    },

    // Draw the custom content into the cells
    CustomDraw = (g, tc) =>
    {
        ((Task)tc.Data).Draw(g, tc.Width, tc.Height);
    }
};

// Cell Style to set back color for even rows
var evenRowStyle = new CellStyle(ta.DefaultCellStyle)
{    
    FillColor = Color.FromArgb(250, 250, 250)   
};

// Add data cells with custom content
ta.AddCell(1, 1, new Task("Requirement Gathering", "In Progress"));
ta.AddCell(1, 2, new Task("Competitive Analysis", "Yet To Start"));
ta.AddCell(1, 3, new Task("Implementation", "On Hold"));
ta.AddCell(1, 4, new Task("Testing", "Completed"));
ta.AddCell(1, 5, new Task("Marketing", "Cancelled"));

ta.AddCell(evenRowStyle, 2, 1, new Task("Testing", "Yet To Start"));
ta.AddCell(evenRowStyle, 2, 2, new Task("Requirement Gathering", "On Hold"));
ta.AddCell(evenRowStyle, 2, 3, new Task("Marketing", "Completed"));
ta.AddCell(evenRowStyle, 2, 4, new Task("Requirement Gathering", "Cancelled"));
ta.AddCell(evenRowStyle, 2, 5, new Task("Implementation", "Yet To Start"));

ta.AddCell(3, 1, new Task("Competitive Analysis", "In Progress"));
ta.AddCell(3, 2, new Task("Implementation", "Completed"));
ta.AddCell(3, 3, new Task("Testing", "Yet To Start"));
ta.AddCell(3, 4, new Task("Implementation", "Cancelled"));
ta.AddCell(3, 5, new Task("Testing", "On Hold"));

ta.AddCell(evenRowStyle, 4, 1, new Task("Marketing", "In Progress"));
ta.AddCell(evenRowStyle, 4, 2, new Task("Marketing", "Completed"));
ta.AddCell(evenRowStyle, 4, 3, new Task("Requirement Gathering", "On Hold"));
ta.AddCell(evenRowStyle, 4, 4, new Task("Marketing", "Yet To Start"));
ta.AddCell(evenRowStyle, 4, 5, new Task("Competitive Analysis", "Cancelled"));

ta.AddCell(5, 1, new Task("Implementation", "On Hold"));
ta.AddCell(5, 2, new Task("Testing", "Yet To Start"));
ta.AddCell(5, 3, new Task("Competitive Analysis", "In Progress"));
ta.AddCell(5, 4, new Task("Competitive Analysis", "Cancelled"));
ta.AddCell(5, 5, new Task("Requirement Gathering", "Completed"));

// Draw the table.
ta.Render();

// Save the PDF document.
doc.Save("custom-content.pdf");

//Class to generate custom content
class Task
{
    public string Title;
    public string Status;

    public Task(string title, string status)
    {
        Title = title;
        Status = status;
    }

    public void Draw(GcGraphics g, float w, float h)
    {
        RectangleF rc;
        var pen = new Pen(Color.Black, 1);
        TextFormat tf = new TextFormat()
        {
            FontName = "Roboto",
            FontSize = 12,
            FontBold = false            
        };


        switch (Status)
        {
            case "Yet To Start":
                rc = new RectangleF(w / 2 - 35, h - 40, 70, 20);
                g.FillRectangle(rc, Color.FromArgb(253, 232, 255));                
                g.DrawRoundRect(rc, 3, Color.FromArgb(136, 0, 214));
                g.DrawString(Status.ToString(), tf, rc, TextAlignment.Center, ParagraphAlignment.Center);
                break;
            case "In Progress":
                rc = new RectangleF(w / 2 - 35, h - 40, 70, 20);
                g.FillRectangle(rc, Color.FromArgb(255,252,232));
                g.DrawRoundRect(rc, 3, Color.FromArgb(214, 186, 0));
                g.DrawString(Status.ToString(), tf, rc, TextAlignment.Center, ParagraphAlignment.Center);
                break;
            case "On Hold":
                rc = new RectangleF(w / 2 - 35, h - 40, 70, 20);
                g.FillRectangle(rc, Color.FromArgb(255,232,232));
                g.DrawRoundRect(rc, 3, Color.FromArgb(214, 0, 0));
                g.DrawString(Status.ToString(), tf, rc, TextAlignment.Center, ParagraphAlignment.Center);
                break;
            case "Completed":
                rc = new RectangleF(w / 2 - 35, h - 40, 70, 20);
                g.FillRectangle(rc, Color.FromArgb(232,255,234));
                g.DrawRoundRect(rc, 3, Color.FromArgb(0, 214, 36));
                g.DrawString(Status.ToString(), tf, rc, TextAlignment.Center, ParagraphAlignment.Center);
                break;
            case "Cancelled":
                rc = new RectangleF(w / 2 - 35, h - 40, 70, 20);
                g.FillRectangle(rc, Color.FromArgb(236, 236, 236));
                g.DrawRoundRect(rc, 3, Color.FromArgb(180, 180, 180));
                tf.ForeColor = Color.FromArgb(119, 119, 119);
                g.DrawString(Status.ToString(), tf, rc, TextAlignment.Center, ParagraphAlignment.Center);
                break;
        }
    }
}


